import { Emitter } from '@zodash/emitter';
import { Step, Progress } from './type';
export interface PipelineConfig {
    name: string;
}
export interface PipelineMiddleware {
    (ctx: PipelineContext, next: Function): void;
}
export interface PipelineProcessor<T> {
    (step: Step<T>, progress: Progress, ctx: PipelineContext): Promise<void>;
}
export interface PipelineContext {
    name: string;
    config: PipelineConfig;
    middlewares: PipelineMiddleware[];
    steps: Step<any>[];
    progress: Progress;
}
export interface PipelineEvent {
    start(ctx: PipelineContext): void;
    prepareStart(ctx: PipelineContext): void;
    prepareFinish(ctx: PipelineContext): void;
    stepStart(step: Step<any>, progress: Progress): void;
    stepFinish(step?: Step<any>, progress?: Progress): void;
    finish(ctx: PipelineContext): void;
    error(error: Error, step?: Step<any>, progress?: Progress): void;
    fatal(error: Error): void;
    progress(progress: Progress, currentStep?: Step<any>): void;
}
export declare class Pipeline extends Emitter<PipelineEvent> {
    private readonly config;
    private ctx;
    constructor(config: PipelineConfig);
    private createContext;
    private createHandler;
    private setSteps;
    private resetProgress;
    private setCurrentStep;
    private setCurrentProgress;
    private getCurrentStep;
    private getCurrentProgress;
    private updateCurrentStepStatus;
    get name(): string;
    use(...middleware: PipelineMiddleware[]): this;
    addProcessor(processor: PipelineProcessor<any>): void;
    run<T>(steps: Step<T>[]): Promise<void>;
}
